library(ape)
library(phangorn)
library(phytools)

#Calculate Missing Data
GB.align<-read.dna(file = "GB_alginment.phy",format = "sequential",as.character = T)
GB.Miss<-gsub("?","-",GB.align, fixed = T)#Convert ?(i.e. missing) to - to count gaps
GB.Gap.Count<-del.rowgapsonly(GB.Miss, threshold = 1, freq.only = TRUE)#Count Gap positions
GB.Miss.Percent<-100-(sum(GB.Gap.Count)/(dim(GB.align)[1]*dim(GB.align)[2])*100)

AB.align<-read.dna(file = "AB_alignment.phy",format = "sequential",as.character = T)
AB.Miss<-gsub("?","-",AB.align, fixed = T)#Convert ?(i.e. missing) to - to count gaps
AB.Gap.Count<-del.rowgapsonly(AB.Miss, threshold = 1, freq.only = TRUE)#Count Gap positions
AB.Miss.Percent<-100-(sum(AB.Gap.Count)/(dim(AB.align)[1]*dim(AB.align)[2])*100)

#Read in bootstrap trees
AB<-read.tree("RAxML_bipartitions.AB_Extract")
GenBank<-read.tree("RAxML_bipartitions.GB_Extract")

tree.comp<-comparePhylo(AB,GenBank)#Find shared bipartitions
AB.shared.nodes<-as.numeric(lapply(strsplit(split = " ",x = as.character(tree.comp$NODES$AB), perl = T),"[[",1))#Extract BS for AB shared bipartitions
GB.shared.nodes<-as.numeric(lapply(strsplit(split = " ",x = as.character(tree.comp$NODES$GenBank), perl = T),"[[",1))#extract BS for GB shared bipartitions

#Calculate mean support for shared bipartitions
mean(as.numeric(AB.shared.nodes),na.rm = TRUE)
mean(as.numeric(GB.shared.nodes),na.rm = TRUE)

#Create cophylo figure setup
co.trees<-cophylo(AB,GenBank)

#Set up color bar for nodal BS values
rbPal <- colorRampPalette(c('blue','red'))
colorsAB<- rbPal(10)[as.numeric(cut(as.numeric(AB$node.label),breaks = 10))]
colorsGB<- rbPal(10)[as.numeric(cut(as.numeric(GenBank$node.label),breaks = 10))]
dat<-as.data.frame(rbind(cbind(colorsAB,AB$node.label),cbind(colorsGB,GenBank$node.label)),stringsAsFactors = FALSE)
dat<-dat[!dat[,2]=="",]
dat<-as.data.frame(dat)
dat$V2<-as.numeric(dat$V2)
order.dat<-dat[order(dat$V2),]

#Generate figure
par(mar=c(0,0,1,0))
plot(co.trees,fsize=.5,pts=0)
nodelabels.cophylo(pie=NULL,col=colorsAB,cex=0.9,pch=16)
nodelabels.cophylo(pie=NULL,col=colorsGB,cex=0.9,pch=16, which="right")
add.color.bar(leg=.16, order.dat$colorsAB, title="Bootstrap Support", lims=c(3,100), digits=1, prompt=TRUE,
              lwd=2, outline=FALSE,fsize=0.85)
